# Contributing

When contributing to this repository, it is always a good idea to first
discuss the change you wish to make via issue, email, or any other method with
the owners of this repository before making a change.

We welcome all kinds of contribution -- code or non-code -- and value them
highly. We pledge to treat everyones contribution fairly and with respect and
we are here to help awesome pull requests over the finish line.

Please note we have a code of conduct, and follow it in all your interactions with the project.

We follow the [NumFOCUS code of conduct](https://numfocus.org/code-of-conduct).

# Developing

You can install all development dependencies via:

    pip install -e .[dev]
    pre-commit install

This will also setup hooks in your local repository to run linting and code
formatting checks prior to making a commit.

# Pull requests

Make sure to include the following with your pull requests:

- description,
- links to relevant issues,
- any necessary code changes,
- unit tests for these changes,
- changes to relevant documentation sections
